netapp_ontap.models.app_cifs_access API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.app_cifs_access`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AppCifsAccessSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AppCifsAccess object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `access GET POST`

    The CIFS access granted to the user or group.

    Valid choices:

    - change
    - full_control
    - no_access
    - read
  `user_or_group GET POST`

    The name of the CIFS user or group that will be granted access.